Thanks for contributing to OpenFisca ! Please remove this line, as well as, for each line below, the cases which are not relevant to your contribution :)

* Tax and benefit system evolution. | Technical improvement. | Crash fix. | Minor change.
* Impacted periods: all. | until DD/MM/YYYY. | from DD/MM/YYYY.
* Impacted areas: `path/to/file/containing/impacted/variables`
* Details:
  - New feature or new behaviour description
  - Cases for which an error was noticed

- - - -

These changes _(remove lines which are not relevant to your contribution)_:

- Impact the OpenFisca-UK public API (for instance renaming or removing a variable)
- Add a new feature (for instance adding a variable)
- Fix or improve an already existing calculation.
- Change non-functional parts of this repository (for instance editing the README)
